
# Slot: subject


behavior that is the subject of the association

URI: [biolink:behavior_to_behavioral_feature_association_subject](https://w3id.org/biolink/vocab/behavior_to_behavioral_feature_association_subject)


## Domain and Range

[BehaviorToBehavioralFeatureAssociation](BehaviorToBehavioralFeatureAssociation.md) &#8594;  <sub>1..1</sub> [Behavior](Behavior.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [BehaviorToBehavioralFeatureAssociation](BehaviorToBehavioralFeatureAssociation.md)
